summaryrefslogtreecommitdiff
path: root/fml/lib/FML/Header.pm
diff options
context:
space:
mode:
authorfukachan <fukachan>2007-01-16 11:02:48 +0000
committerfukachan <fukachan>2007-01-16 11:02:48 +0000
commit9a763f6e605b39349286d0b0ed3ed617191fc4f6 (patch)
tree29fdb7f513fdbf317dcb469880030bea2207e4b8 /fml/lib/FML/Header.pm
parent8dcc322858925063b4f81f6cd2b6de81698a63a3 (diff)
downloadfml8-9a763f6e605b39349286d0b0ed3ed617191fc4f6.tar.gz
fml8-9a763f6e605b39349286d0b0ed3ed617191fc4f6.tar.bz2
fml8-9a763f6e605b39349286d0b0ed3ed617191fc4f6.zip
fix comments
Diffstat (limited to 'fml/lib/FML/Header.pm')
-rw-r--r--fml/lib/FML/Header.pm20
1 files changed, 13 insertions, 7 deletions
diff --git a/fml/lib/FML/Header.pm b/fml/lib/FML/Header.pm
index 7f1808c7..957393af 100644
--- a/fml/lib/FML/Header.pm
+++ b/fml/lib/FML/Header.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Header.pm,v 1.92 2006/04/17 12:00:50 fukachan Exp $
+# $FML: Header.pm,v 1.93 2006/07/09 12:11:12 fukachan Exp $
#
package FML::Header;
@@ -56,12 +56,13 @@ C<FML::Header> overloads C<get()> to remove the trailing "\n".
=head2 new()
+constructor.
forward the request up to superclass C<Mail::header::new()>.
=cut
-# Descriptions: forward new() request to the base class.
+# Descriptions: forward new() request to the base class Mail::header.
# Arguments: OBJ($self) HASH_REF($rw_args)
# Side Effects: none
# Return Value: OBJ
@@ -122,7 +123,11 @@ sub set
=head2 address_cleanup(address)
clean up given C<address>. This method parses the given address by
-C<Mail::Address::parse()>, remove < and > and return the result.
+C<Mail::Address::parse()>, remove < and > and return the result
+if the result is not empty.
+
+return the raw "<>" if the specified address is "<>"
+since we should not remove <> from "<>" special address.
=cut
@@ -218,7 +223,7 @@ add X-ML-Count: field.
#
# Descriptions: add "X-ML-Name: elena" to header.
# Arguments: OBJ($header) OBJ($config) HASH_REF($rw_args)
# Side Effects: update $header
# Return Value: none
@@ -402,7 +407,7 @@ sub add_message_id
}
# Descriptions: add "X-Sequence: elena NUM" to header.
# Arguments: OBJ($header) OBJ($config) HASH_REF($rw_args)
# Side Effects: update $header
# Return Value: none
@@ -420,11 +425,12 @@ sub add_x_sequence
=head2 rewrite_subject_tag($config, $rw_args)
=head2 rewrite_article_subject_tag($config, $rw_args)
-add subject tag like [elena:00010].
+add subject tag like [ML_NAME:00010] e.g. [elena:00010] for elena ML.
The actual function definitions exist in C<FML::Header::Subject>.
=cut
+
# Descriptions: rewrite subject if needed.
# Arguments: OBJ($header) OBJ($config) HASH_REF($rw_args)
# Side Effects: update $header
@@ -526,7 +532,7 @@ sub rewrite_reply_to
=head2 rewrite_reply_to_enforce_article_post_address
-enfoece replacement of C<Reply-To:> with this ML's address for post.
+enforce replacement of C<Reply-To:> with this ML's address for post.
=cut
@@ -218,7 +223,7 @@ add X-ML-Count: field.
#
-# Descriptions: add "X-ML-Name: elena" to header.
+# Descriptions: add "X-ML-Name: ML_NAME" to the mail header.
# Arguments: OBJ($header) OBJ($config) HASH_REF($rw_args)
# Side Effects: update $header
@@ -402,7 +407,7 @@ sub add_message_id
}
-# Descriptions: add "X-Sequence: elena NUM" to header.
+# Descriptions: add "X-Sequence: ML_NAME NUM" to header.
# Arguments: OBJ($header) OBJ($config) HASH_REF($rw_args)
# Side Effects: update $header